@@ -29,6 +29,8 @@ from .instance import (
     ValidatorType,
     ExecuteFunctionResponse,
 )
+from .config import DEFAULT_MAX_RETRIES, DEFAULT_TIMEOUT, REGION_BASE_URL
+from .instance.base import default_httpx_client
 from .resources.base import Resource
 from .resources.sqlite import SQLiteResource
 from .resources.browser import BrowserResource
@@ -36,16 +38,23 @@ from .resources.browser import BrowserResource
 logger = logging.getLogger(__name__)
 
 
+def _delete_instance(client: SyncWrapper, instance_id: str) -> InstanceRecord:
+    response = client.request("DELETE", f"/v1/env/instances/{instance_id}")
+    return InstanceRecord(**response.json())
+
+
 class Environment(EnvironmentBase):
-    def __init__(self, httpx_client: Optional[httpx.Client] = None, **kwargs):
+    def __init__(self, client: SyncWrapper, **kwargs):
         super().__init__(**kwargs)
-        self._httpx_client = httpx_client or httpx.Client(timeout=60.0)
+        self._client = client
         self._instance: Optional[InstanceClient] = None
 
     @property
     def instance(self) -> InstanceClient:
         if self._instance is None:
-            self._instance = InstanceClient(self.manager_url, self._httpx_client)
+            self._instance = InstanceClient(
+                self.manager_url, self._client.httpx_client
+            )
         return self._instance
 
     def reset(
@@ -66,7 +75,7 @@ class Environment(EnvironmentBase):
         return self.instance.resources()
 
     def close(self) -> InstanceRecord:
-        return Fleet().delete(self.instance_id)
+        return _delete_instance(self._client, self.instance_id)
 
     def verify(self, validator: ValidatorType) -> ExecuteFunctionResponse:
         return self.instance.verify(validator)
@@ -83,8 +92,10 @@ class Fleet:
         api_key: Optional[str] = os.getenv("FLEET_API_KEY"),
         base_url: Optional[str] = None,
         httpx_client: Optional[httpx.Client] = None,
+        max_retries: int = DEFAULT_MAX_RETRIES,
+        timeout: float = DEFAULT_TIMEOUT,
     ):
-        self._httpx_client = httpx_client or httpx.Client(timeout=60.0)
+        self._httpx_client = httpx_client or default_httpx_client(max_retries, timeout)
         self.client = SyncWrapper(
             api_key=api_key,
             base_url=base_url,
@@ -95,11 +106,17 @@ class Fleet:
         response = self.client.request("GET", "/v1/env/")
         return [EnvironmentModel(**env_data) for env_data in response.json()]
 
+    def list_regions(self) -> List[str]:
+        response = self.client.request("GET", "/v1/regions")
+        return response.json()
+
     def environment(self, env_key: str) -> EnvironmentModel:
         response = self.client.request("GET", f"/v1/env/{env_key}")
         return EnvironmentModel(**response.json())
 
-    def make(self, env_key: str) -> Environment:
+    def make(
+        self, env_key: str, region: Optional[str] = None
+    ) -> Environment:
         if ":" in env_key:
             env_key_part, version = env_key.split(":", 1)
             if not version.startswith("v"):
@@ -108,26 +125,38 @@ class Fleet:
             env_key_part = env_key
             version = None
 
-        request = InstanceRequest(env_key=env_key_part, version=version)
+        request = InstanceRequest(env_key=env_key_part, version=version, region=region)
+        region_base_url = REGION_BASE_URL.get(region)
         response = self.client.request(
-            "POST", "/v1/env/instances", json=request.model_dump()
+            "POST",
+            "/v1/env/instances",
+            json=request.model_dump(),
+            base_url=region_base_url,
         )
-        instance = Environment(**response.json())
+        instance = Environment(client=self.client, **response.json())
         instance.instance.load()
         return instance
 
-    def instances(self, status: Optional[str] = None) -> List[Environment]:
+    def instances(
+        self, status: Optional[str] = None, region: Optional[str] = None
+    ) -> List[Environment]:
         params = {}
         if status:
             params["status"] = status
+        if region:
+            params["region"] = region
 
         response = self.client.request("GET", "/v1/env/instances", params=params)
-        return [Environment(**instance_data) for instance_data in response.json()]
+        return [
+            Environment(client=self.client, **instance_data)
+            for instance_data in response.json()
+        ]
 
     def instance(self, instance_id: str) -> Environment:
         response = self.client.request("GET", f"/v1/env/instances/{instance_id}")
-        return Environment(**response.json())
+        instance = Environment(client=self.client, **response.json())
+        instance.instance.load()
+        return instance
 
     def delete(self, instance_id: str) -> InstanceRecord:
-        response = self.client.request("DELETE", f"/v1/env/instances/{instance_id}")
-        return InstanceRecord(**response.json())
\ No newline at end of file
+        return _delete_instance(self.client, instance_id)
